@@ -2,7 +2,7 @@
  * Decoding of OEM-specific entries
  * This file is part of the dmidecode project.
  *
- *   (C) 2007 Jean Delvare <khali@linux-fr.org>
+ *   Copyright (C) 2007-2008 Jean Delvare <khali@linux-fr.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,4 +22,4 @@
 struct dmi_header;
 
 void dmi_set_vendor(const char *s);
-int dmi_decode_oem(struct dmi_header *h);
+int dmi_decode_oem(const struct dmi_header *h);
